# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import markets_pb2 as markets__pb2
from . import assets_pb2 as assets__pb2
from . import governance_pb2 as governance__pb2
from . import vega_pb2 as vega__pb2
from .oracles.v1 import oracle_spec_pb2 as oracles_dot_v1_dot_oracle__spec__pb2
from .oracles.v1 import oracle_data_pb2 as oracles_dot_v1_dot_oracle__data__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='events.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'\n\024io.vegaprotocol.vegaZ\037code.vegaprotocol.io/vega/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x65vents.proto\x12\x04vega\x1a\rmarkets.proto\x1a\x0c\x61ssets.proto\x1a\x10governance.proto\x1a\nvega.proto\x1a\x1coracles/v1/oracle_spec.proto\x1a\x1coracles/v1/oracle_data.proto\"D\n\x0bMarketEvent\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x18\n\x07payload\x18\x02 \x01(\tR\x07payload\"\xf0\x02\n\x0cTxErrorEvent\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x17\n\x07\x65rr_msg\x18\x02 \x01(\tR\x06\x65rrMsg\x12\x42\n\x10order_submission\x18\x65 \x01(\x0b\x32\x15.vega.OrderSubmissionH\x00R\x0forderSubmission\x12?\n\x0forder_amendment\x18\x66 \x01(\x0b\x32\x14.vega.OrderAmendmentH\x00R\x0eorderAmendment\x12H\n\x12order_cancellation\x18g \x01(\x0b\x32\x17.vega.OrderCancellationH\x00R\x11orderCancellation\x12,\n\x08proposal\x18h \x01(\x0b\x32\x0e.vega.ProposalH\x00R\x08proposal\x12 \n\x04vote\x18i \x01(\x0b\x32\n.vega.VoteH\x00R\x04voteB\r\n\x0btransaction\"*\n\nTimeUpdate\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\"I\n\x11TransferResponses\x12\x34\n\tresponses\x18\x01 \x03(\x0b\x32\x16.vega.TransferResponseR\tresponses\"\x88\x01\n\x12PositionResolution\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1e\n\ndistressed\x18\x02 \x01(\x03R\ndistressed\x12\x16\n\x06\x63losed\x18\x03 \x01(\x03R\x06\x63losed\x12\x1d\n\nmark_price\x18\x04 \x01(\x04R\tmarkPrice\"c\n\x11LossSocialization\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x16\n\x06\x61mount\x18\x03 \x01(\x03R\x06\x61mount\";\n\x0fTradeSettlement\x12\x12\n\x04size\x18\x01 \x01(\x03R\x04size\x12\x14\n\x05price\x18\x02 \x01(\x04R\x05price\"\xa2\x01\n\x0eSettlePosition\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x14\n\x05price\x18\x03 \x01(\x04R\x05price\x12\x42\n\x11trade_settlements\x18\x04 \x03(\x0b\x32\x15.vega.TradeSettlementR\x10tradeSettlements\"x\n\x10SettleDistressed\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x16\n\x06margin\x18\x03 \x01(\x04R\x06margin\x12\x14\n\x05price\x18\x04 \x01(\x04R\x05price\"0\n\nMarketTick\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04time\x18\x02 \x01(\x03R\x04time\"\xc2\x01\n\x0c\x41uctionEvent\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\'\n\x0fopening_auction\x18\x02 \x01(\x08R\x0eopeningAuction\x12\x14\n\x05leave\x18\x03 \x01(\x08R\x05leave\x12\x14\n\x05start\x18\x04 \x01(\x03R\x05start\x12\x10\n\x03\x65nd\x18\x05 \x01(\x03R\x03\x65nd\x12.\n\x07trigger\x18\x06 \x01(\x0e\x32\x14.vega.AuctionTriggerR\x07trigger\"\x94\r\n\x08\x42usEvent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x62lock\x18\x02 \x01(\tR\x05\x62lock\x12&\n\x04type\x18\x03 \x01(\x0e\x32\x12.vega.BusEventTypeR\x04type\x12\x33\n\x0btime_update\x18\x65 \x01(\x0b\x32\x10.vega.TimeUpdateH\x00R\ntimeUpdate\x12H\n\x12transfer_responses\x18\x66 \x01(\x0b\x32\x17.vega.TransferResponsesH\x00R\x11transferResponses\x12K\n\x13position_resolution\x18g \x01(\x0b\x32\x18.vega.PositionResolutionH\x00R\x12positionResolution\x12#\n\x05order\x18h \x01(\x0b\x32\x0b.vega.OrderH\x00R\x05order\x12)\n\x07\x61\x63\x63ount\x18i \x01(\x0b\x32\r.vega.AccountH\x00R\x07\x61\x63\x63ount\x12#\n\x05party\x18j \x01(\x0b\x32\x0b.vega.PartyH\x00R\x05party\x12#\n\x05trade\x18k \x01(\x0b\x32\x0b.vega.TradeH\x00R\x05trade\x12\x39\n\rmargin_levels\x18l \x01(\x0b\x32\x12.vega.MarginLevelsH\x00R\x0cmarginLevels\x12,\n\x08proposal\x18m \x01(\x0b\x32\x0e.vega.ProposalH\x00R\x08proposal\x12 \n\x04vote\x18n \x01(\x0b\x32\n.vega.VoteH\x00R\x04vote\x12\x33\n\x0bmarket_data\x18o \x01(\x0b\x32\x10.vega.MarketDataH\x00R\nmarketData\x12<\n\x0enode_signature\x18p \x01(\x0b\x32\x13.vega.NodeSignatureH\x00R\rnodeSignature\x12H\n\x12loss_socialization\x18q \x01(\x0b\x32\x17.vega.LossSocializationH\x00R\x11lossSocialization\x12?\n\x0fsettle_position\x18r \x01(\x0b\x32\x14.vega.SettlePositionH\x00R\x0esettlePosition\x12\x45\n\x11settle_distressed\x18s \x01(\x0b\x32\x16.vega.SettleDistressedH\x00R\x10settleDistressed\x12\x35\n\x0emarket_created\x18t \x01(\x0b\x32\x0c.vega.MarketH\x00R\rmarketCreated\x12#\n\x05\x61sset\x18u \x01(\x0b\x32\x0b.vega.AssetH\x00R\x05\x61sset\x12\x33\n\x0bmarket_tick\x18v \x01(\x0b\x32\x10.vega.MarketTickH\x00R\nmarketTick\x12\x32\n\nwithdrawal\x18w \x01(\x0b\x32\x10.vega.WithdrawalH\x00R\nwithdrawal\x12)\n\x07\x64\x65posit\x18x \x01(\x0b\x32\r.vega.DepositH\x00R\x07\x64\x65posit\x12.\n\x07\x61uction\x18y \x01(\x0b\x32\x12.vega.AuctionEventH\x00R\x07\x61uction\x12\x33\n\x0brisk_factor\x18z \x01(\x0b\x32\x10.vega.RiskFactorH\x00R\nriskFactor\x12\x45\n\x11network_parameter\x18{ \x01(\x0b\x32\x16.vega.NetworkParameterH\x00R\x10networkParameter\x12K\n\x13liquidity_provision\x18| \x01(\x0b\x32\x18.vega.LiquidityProvisionH\x00R\x12liquidityProvision\x12\x35\n\x0emarket_updated\x18} \x01(\x0b\x32\x0c.vega.MarketH\x00R\rmarketUpdated\x12\x39\n\x0boracle_spec\x18~ \x01(\x0b\x32\x16.oracles.v1.OracleSpecH\x00R\noracleSpec\x12\x39\n\x0boracle_data\x18\x7f \x01(\x0b\x32\x16.oracles.v1.OracleDataH\x00R\noracleData\x12,\n\x06market\x18\xe9\x07 \x01(\x0b\x32\x11.vega.MarketEventH\x00R\x06market\x12\x37\n\x0ctx_err_event\x18\xd1\x0f \x01(\x0b\x32\x12.vega.TxErrorEventH\x00R\ntxErrEventB\x07\n\x05\x65vent*\xe9\x07\n\x0c\x42usEventType\x12\x1e\n\x1a\x42US_EVENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x42US_EVENT_TYPE_ALL\x10\x01\x12\x1e\n\x1a\x42US_EVENT_TYPE_TIME_UPDATE\x10\x02\x12%\n!BUS_EVENT_TYPE_TRANSFER_RESPONSES\x10\x03\x12&\n\"BUS_EVENT_TYPE_POSITION_RESOLUTION\x10\x04\x12\x18\n\x14\x42US_EVENT_TYPE_ORDER\x10\x05\x12\x1a\n\x16\x42US_EVENT_TYPE_ACCOUNT\x10\x06\x12\x18\n\x14\x42US_EVENT_TYPE_PARTY\x10\x07\x12\x18\n\x14\x42US_EVENT_TYPE_TRADE\x10\x08\x12 \n\x1c\x42US_EVENT_TYPE_MARGIN_LEVELS\x10\t\x12\x1b\n\x17\x42US_EVENT_TYPE_PROPOSAL\x10\n\x12\x17\n\x13\x42US_EVENT_TYPE_VOTE\x10\x0b\x12\x1e\n\x1a\x42US_EVENT_TYPE_MARKET_DATA\x10\x0c\x12!\n\x1d\x42US_EVENT_TYPE_NODE_SIGNATURE\x10\r\x12%\n!BUS_EVENT_TYPE_LOSS_SOCIALIZATION\x10\x0e\x12\"\n\x1e\x42US_EVENT_TYPE_SETTLE_POSITION\x10\x0f\x12$\n BUS_EVENT_TYPE_SETTLE_DISTRESSED\x10\x10\x12!\n\x1d\x42US_EVENT_TYPE_MARKET_CREATED\x10\x11\x12\x18\n\x14\x42US_EVENT_TYPE_ASSET\x10\x12\x12\x1e\n\x1a\x42US_EVENT_TYPE_MARKET_TICK\x10\x13\x12\x1d\n\x19\x42US_EVENT_TYPE_WITHDRAWAL\x10\x14\x12\x1a\n\x16\x42US_EVENT_TYPE_DEPOSIT\x10\x15\x12\x1a\n\x16\x42US_EVENT_TYPE_AUCTION\x10\x16\x12\x1e\n\x1a\x42US_EVENT_TYPE_RISK_FACTOR\x10\x17\x12$\n BUS_EVENT_TYPE_NETWORK_PARAMETER\x10\x18\x12&\n\"BUS_EVENT_TYPE_LIQUIDITY_PROVISION\x10\x19\x12!\n\x1d\x42US_EVENT_TYPE_MARKET_UPDATED\x10\x1a\x12\x1e\n\x1a\x42US_EVENT_TYPE_ORACLE_SPEC\x10\x1b\x12\x1e\n\x1a\x42US_EVENT_TYPE_ORACLE_DATA\x10\x1c\x12\x19\n\x15\x42US_EVENT_TYPE_MARKET\x10\x65\x12\x1c\n\x17\x42US_EVENT_TYPE_TX_ERROR\x10\xc9\x01\x42\x37\n\x14io.vegaprotocol.vegaZ\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[markets__pb2.DESCRIPTOR,assets__pb2.DESCRIPTOR,governance__pb2.DESCRIPTOR,vega__pb2.DESCRIPTOR,oracles_dot_v1_dot_oracle__spec__pb2.DESCRIPTOR,oracles_dot_v1_dot_oracle__data__pb2.DESCRIPTOR,])

_BUSEVENTTYPE = _descriptor.EnumDescriptor(
  name='BusEventType',
  full_name='vega.BusEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TIME_UPDATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TRANSFER_RESPONSES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_POSITION_RESOLUTION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ORDER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ACCOUNT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_PARTY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TRADE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARGIN_LEVELS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_PROPOSAL', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_VOTE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_DATA', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_NODE_SIGNATURE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_LOSS_SOCIALIZATION', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_SETTLE_POSITION', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_SETTLE_DISTRESSED', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_CREATED', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ASSET', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_TICK', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_WITHDRAWAL', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_DEPOSIT', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_AUCTION', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_RISK_FACTOR', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_NETWORK_PARAMETER', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_LIQUIDITY_PROVISION', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_UPDATED', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ORACLE_SPEC', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ORACLE_DATA', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET', index=29, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TX_ERROR', index=30, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3224,
  serialized_end=4225,
)
_sym_db.RegisterEnumDescriptor(_BUSEVENTTYPE)

BusEventType = enum_type_wrapper.EnumTypeWrapper(_BUSEVENTTYPE)
BUS_EVENT_TYPE_UNSPECIFIED = 0
BUS_EVENT_TYPE_ALL = 1
BUS_EVENT_TYPE_TIME_UPDATE = 2
BUS_EVENT_TYPE_TRANSFER_RESPONSES = 3
BUS_EVENT_TYPE_POSITION_RESOLUTION = 4
BUS_EVENT_TYPE_ORDER = 5
BUS_EVENT_TYPE_ACCOUNT = 6
BUS_EVENT_TYPE_PARTY = 7
BUS_EVENT_TYPE_TRADE = 8
BUS_EVENT_TYPE_MARGIN_LEVELS = 9
BUS_EVENT_TYPE_PROPOSAL = 10
BUS_EVENT_TYPE_VOTE = 11
BUS_EVENT_TYPE_MARKET_DATA = 12
BUS_EVENT_TYPE_NODE_SIGNATURE = 13
BUS_EVENT_TYPE_LOSS_SOCIALIZATION = 14
BUS_EVENT_TYPE_SETTLE_POSITION = 15
BUS_EVENT_TYPE_SETTLE_DISTRESSED = 16
BUS_EVENT_TYPE_MARKET_CREATED = 17
BUS_EVENT_TYPE_ASSET = 18
BUS_EVENT_TYPE_MARKET_TICK = 19
BUS_EVENT_TYPE_WITHDRAWAL = 20
BUS_EVENT_TYPE_DEPOSIT = 21
BUS_EVENT_TYPE_AUCTION = 22
BUS_EVENT_TYPE_RISK_FACTOR = 23
BUS_EVENT_TYPE_NETWORK_PARAMETER = 24
BUS_EVENT_TYPE_LIQUIDITY_PROVISION = 25
BUS_EVENT_TYPE_MARKET_UPDATED = 26
BUS_EVENT_TYPE_ORACLE_SPEC = 27
BUS_EVENT_TYPE_ORACLE_DATA = 28
BUS_EVENT_TYPE_MARKET = 101
BUS_EVENT_TYPE_TX_ERROR = 201



_MARKETEVENT = _descriptor.Descriptor(
  name='MarketEvent',
  full_name='vega.MarketEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.MarketEvent.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='vega.MarketEvent.payload', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='payload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=209,
)


_TXERROREVENT = _descriptor.Descriptor(
  name='TxErrorEvent',
  full_name='vega.TxErrorEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.TxErrorEvent.party_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='err_msg', full_name='vega.TxErrorEvent.err_msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errMsg', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_submission', full_name='vega.TxErrorEvent.order_submission', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_amendment', full_name='vega.TxErrorEvent.order_amendment', index=3,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderAmendment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_cancellation', full_name='vega.TxErrorEvent.order_cancellation', index=4,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderCancellation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal', full_name='vega.TxErrorEvent.proposal', index=5,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='proposal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote', full_name='vega.TxErrorEvent.vote', index=6,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vote', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='transaction', full_name='vega.TxErrorEvent.transaction',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=212,
  serialized_end=580,
)


_TIMEUPDATE = _descriptor.Descriptor(
  name='TimeUpdate',
  full_name='vega.TimeUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.TimeUpdate.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=624,
)


_TRANSFERRESPONSES = _descriptor.Descriptor(
  name='TransferResponses',
  full_name='vega.TransferResponses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='vega.TransferResponses.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='responses', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=699,
)


_POSITIONRESOLUTION = _descriptor.Descriptor(
  name='PositionResolution',
  full_name='vega.PositionResolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.PositionResolution.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distressed', full_name='vega.PositionResolution.distressed', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distressed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closed', full_name='vega.PositionResolution.closed', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='closed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_price', full_name='vega.PositionResolution.mark_price', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='markPrice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=838,
)


_LOSSSOCIALIZATION = _descriptor.Descriptor(
  name='LossSocialization',
  full_name='vega.LossSocialization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.LossSocialization.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.LossSocialization.party_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.LossSocialization.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=840,
  serialized_end=939,
)


_TRADESETTLEMENT = _descriptor.Descriptor(
  name='TradeSettlement',
  full_name='vega.TradeSettlement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='vega.TradeSettlement.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.TradeSettlement.price', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=1000,
)


_SETTLEPOSITION = _descriptor.Descriptor(
  name='SettlePosition',
  full_name='vega.SettlePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.SettlePosition.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.SettlePosition.party_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.SettlePosition.price', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_settlements', full_name='vega.SettlePosition.trade_settlements', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tradeSettlements', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1003,
  serialized_end=1165,
)


_SETTLEDISTRESSED = _descriptor.Descriptor(
  name='SettleDistressed',
  full_name='vega.SettleDistressed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.SettleDistressed.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.SettleDistressed.party_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='vega.SettleDistressed.margin', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='margin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.SettleDistressed.price', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1287,
)


_MARKETTICK = _descriptor.Descriptor(
  name='MarketTick',
  full_name='vega.MarketTick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.MarketTick.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='vega.MarketTick.time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1289,
  serialized_end=1337,
)


_AUCTIONEVENT = _descriptor.Descriptor(
  name='AuctionEvent',
  full_name='vega.AuctionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.AuctionEvent.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opening_auction', full_name='vega.AuctionEvent.opening_auction', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='openingAuction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leave', full_name='vega.AuctionEvent.leave', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='leave', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='vega.AuctionEvent.start', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='start', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='vega.AuctionEvent.end', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='end', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='vega.AuctionEvent.trigger', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='trigger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1534,
)


_BUSEVENT = _descriptor.Descriptor(
  name='BusEvent',
  full_name='vega.BusEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.BusEvent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.BusEvent.block', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='block', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='vega.BusEvent.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_update', full_name='vega.BusEvent.time_update', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeUpdate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer_responses', full_name='vega.BusEvent.transfer_responses', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transferResponses', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_resolution', full_name='vega.BusEvent.position_resolution', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='positionResolution', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='vega.BusEvent.order', index=6,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='order', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='vega.BusEvent.account', index=7,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='account', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party', full_name='vega.BusEvent.party', index=8,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='party', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade', full_name='vega.BusEvent.trade', index=9,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='trade', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin_levels', full_name='vega.BusEvent.margin_levels', index=10,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marginLevels', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal', full_name='vega.BusEvent.proposal', index=11,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='proposal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote', full_name='vega.BusEvent.vote', index=12,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vote', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_data', full_name='vega.BusEvent.market_data', index=13,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_signature', full_name='vega.BusEvent.node_signature', index=14,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeSignature', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loss_socialization', full_name='vega.BusEvent.loss_socialization', index=15,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lossSocialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settle_position', full_name='vega.BusEvent.settle_position', index=16,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='settlePosition', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settle_distressed', full_name='vega.BusEvent.settle_distressed', index=17,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='settleDistressed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_created', full_name='vega.BusEvent.market_created', index=18,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketCreated', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset', full_name='vega.BusEvent.asset', index=19,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_tick', full_name='vega.BusEvent.market_tick', index=20,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketTick', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BusEvent.withdrawal', index=21,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withdrawal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BusEvent.deposit', index=22,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deposit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auction', full_name='vega.BusEvent.auction', index=23,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='auction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='risk_factor', full_name='vega.BusEvent.risk_factor', index=24,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='riskFactor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_parameter', full_name='vega.BusEvent.network_parameter', index=25,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='networkParameter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_provision', full_name='vega.BusEvent.liquidity_provision', index=26,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityProvision', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_updated', full_name='vega.BusEvent.market_updated', index=27,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketUpdated', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_spec', full_name='vega.BusEvent.oracle_spec', index=28,
      number=126, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_data', full_name='vega.BusEvent.oracle_data', index=29,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='vega.BusEvent.market', index=30,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='market', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_err_event', full_name='vega.BusEvent.tx_err_event', index=31,
      number=2001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='txErrEvent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='vega.BusEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1537,
  serialized_end=3221,
)

_TXERROREVENT.fields_by_name['order_submission'].message_type = vega__pb2._ORDERSUBMISSION
_TXERROREVENT.fields_by_name['order_amendment'].message_type = vega__pb2._ORDERAMENDMENT
_TXERROREVENT.fields_by_name['order_cancellation'].message_type = vega__pb2._ORDERCANCELLATION
_TXERROREVENT.fields_by_name['proposal'].message_type = governance__pb2._PROPOSAL
_TXERROREVENT.fields_by_name['vote'].message_type = governance__pb2._VOTE
_TXERROREVENT.oneofs_by_name['transaction'].fields.append(
  _TXERROREVENT.fields_by_name['order_submission'])
_TXERROREVENT.fields_by_name['order_submission'].containing_oneof = _TXERROREVENT.oneofs_by_name['transaction']
_TXERROREVENT.oneofs_by_name['transaction'].fields.append(
  _TXERROREVENT.fields_by_name['order_amendment'])
_TXERROREVENT.fields_by_name['order_amendment'].containing_oneof = _TXERROREVENT.oneofs_by_name['transaction']
_TXERROREVENT.oneofs_by_name['transaction'].fields.append(
  _TXERROREVENT.fields_by_name['order_cancellation'])
_TXERROREVENT.fields_by_name['order_cancellation'].containing_oneof = _TXERROREVENT.oneofs_by_name['transaction']
_TXERROREVENT.oneofs_by_name['transaction'].fields.append(
  _TXERROREVENT.fields_by_name['proposal'])
_TXERROREVENT.fields_by_name['proposal'].containing_oneof = _TXERROREVENT.oneofs_by_name['transaction']
_TXERROREVENT.oneofs_by_name['transaction'].fields.append(
  _TXERROREVENT.fields_by_name['vote'])
_TXERROREVENT.fields_by_name['vote'].containing_oneof = _TXERROREVENT.oneofs_by_name['transaction']
_TRANSFERRESPONSES.fields_by_name['responses'].message_type = vega__pb2._TRANSFERRESPONSE
_SETTLEPOSITION.fields_by_name['trade_settlements'].message_type = _TRADESETTLEMENT
_AUCTIONEVENT.fields_by_name['trigger'].enum_type = vega__pb2._AUCTIONTRIGGER
_BUSEVENT.fields_by_name['type'].enum_type = _BUSEVENTTYPE
_BUSEVENT.fields_by_name['time_update'].message_type = _TIMEUPDATE
_BUSEVENT.fields_by_name['transfer_responses'].message_type = _TRANSFERRESPONSES
_BUSEVENT.fields_by_name['position_resolution'].message_type = _POSITIONRESOLUTION
_BUSEVENT.fields_by_name['order'].message_type = vega__pb2._ORDER
_BUSEVENT.fields_by_name['account'].message_type = vega__pb2._ACCOUNT
_BUSEVENT.fields_by_name['party'].message_type = vega__pb2._PARTY
_BUSEVENT.fields_by_name['trade'].message_type = vega__pb2._TRADE
_BUSEVENT.fields_by_name['margin_levels'].message_type = vega__pb2._MARGINLEVELS
_BUSEVENT.fields_by_name['proposal'].message_type = governance__pb2._PROPOSAL
_BUSEVENT.fields_by_name['vote'].message_type = governance__pb2._VOTE
_BUSEVENT.fields_by_name['market_data'].message_type = vega__pb2._MARKETDATA
_BUSEVENT.fields_by_name['node_signature'].message_type = vega__pb2._NODESIGNATURE
_BUSEVENT.fields_by_name['loss_socialization'].message_type = _LOSSSOCIALIZATION
_BUSEVENT.fields_by_name['settle_position'].message_type = _SETTLEPOSITION
_BUSEVENT.fields_by_name['settle_distressed'].message_type = _SETTLEDISTRESSED
_BUSEVENT.fields_by_name['market_created'].message_type = markets__pb2._MARKET
_BUSEVENT.fields_by_name['asset'].message_type = assets__pb2._ASSET
_BUSEVENT.fields_by_name['market_tick'].message_type = _MARKETTICK
_BUSEVENT.fields_by_name['withdrawal'].message_type = vega__pb2._WITHDRAWAL
_BUSEVENT.fields_by_name['deposit'].message_type = vega__pb2._DEPOSIT
_BUSEVENT.fields_by_name['auction'].message_type = _AUCTIONEVENT
_BUSEVENT.fields_by_name['risk_factor'].message_type = vega__pb2._RISKFACTOR
_BUSEVENT.fields_by_name['network_parameter'].message_type = vega__pb2._NETWORKPARAMETER
_BUSEVENT.fields_by_name['liquidity_provision'].message_type = vega__pb2._LIQUIDITYPROVISION
_BUSEVENT.fields_by_name['market_updated'].message_type = markets__pb2._MARKET
_BUSEVENT.fields_by_name['oracle_spec'].message_type = oracles_dot_v1_dot_oracle__spec__pb2._ORACLESPEC
_BUSEVENT.fields_by_name['oracle_data'].message_type = oracles_dot_v1_dot_oracle__data__pb2._ORACLEDATA
_BUSEVENT.fields_by_name['market'].message_type = _MARKETEVENT
_BUSEVENT.fields_by_name['tx_err_event'].message_type = _TXERROREVENT
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['time_update'])
_BUSEVENT.fields_by_name['time_update'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['transfer_responses'])
_BUSEVENT.fields_by_name['transfer_responses'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['position_resolution'])
_BUSEVENT.fields_by_name['position_resolution'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['order'])
_BUSEVENT.fields_by_name['order'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['account'])
_BUSEVENT.fields_by_name['account'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['party'])
_BUSEVENT.fields_by_name['party'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['trade'])
_BUSEVENT.fields_by_name['trade'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['margin_levels'])
_BUSEVENT.fields_by_name['margin_levels'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['proposal'])
_BUSEVENT.fields_by_name['proposal'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['vote'])
_BUSEVENT.fields_by_name['vote'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['market_data'])
_BUSEVENT.fields_by_name['market_data'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['node_signature'])
_BUSEVENT.fields_by_name['node_signature'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['loss_socialization'])
_BUSEVENT.fields_by_name['loss_socialization'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['settle_position'])
_BUSEVENT.fields_by_name['settle_position'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['settle_distressed'])
_BUSEVENT.fields_by_name['settle_distressed'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['market_created'])
_BUSEVENT.fields_by_name['market_created'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['asset'])
_BUSEVENT.fields_by_name['asset'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['market_tick'])
_BUSEVENT.fields_by_name['market_tick'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['withdrawal'])
_BUSEVENT.fields_by_name['withdrawal'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['deposit'])
_BUSEVENT.fields_by_name['deposit'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['auction'])
_BUSEVENT.fields_by_name['auction'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['risk_factor'])
_BUSEVENT.fields_by_name['risk_factor'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['network_parameter'])
_BUSEVENT.fields_by_name['network_parameter'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['liquidity_provision'])
_BUSEVENT.fields_by_name['liquidity_provision'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['market_updated'])
_BUSEVENT.fields_by_name['market_updated'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['oracle_spec'])
_BUSEVENT.fields_by_name['oracle_spec'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['oracle_data'])
_BUSEVENT.fields_by_name['oracle_data'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['market'])
_BUSEVENT.fields_by_name['market'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['tx_err_event'])
_BUSEVENT.fields_by_name['tx_err_event'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['MarketEvent'] = _MARKETEVENT
DESCRIPTOR.message_types_by_name['TxErrorEvent'] = _TXERROREVENT
DESCRIPTOR.message_types_by_name['TimeUpdate'] = _TIMEUPDATE
DESCRIPTOR.message_types_by_name['TransferResponses'] = _TRANSFERRESPONSES
DESCRIPTOR.message_types_by_name['PositionResolution'] = _POSITIONRESOLUTION
DESCRIPTOR.message_types_by_name['LossSocialization'] = _LOSSSOCIALIZATION
DESCRIPTOR.message_types_by_name['TradeSettlement'] = _TRADESETTLEMENT
DESCRIPTOR.message_types_by_name['SettlePosition'] = _SETTLEPOSITION
DESCRIPTOR.message_types_by_name['SettleDistressed'] = _SETTLEDISTRESSED
DESCRIPTOR.message_types_by_name['MarketTick'] = _MARKETTICK
DESCRIPTOR.message_types_by_name['AuctionEvent'] = _AUCTIONEVENT
DESCRIPTOR.message_types_by_name['BusEvent'] = _BUSEVENT
DESCRIPTOR.enum_types_by_name['BusEventType'] = _BUSEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketEvent = _reflection.GeneratedProtocolMessageType('MarketEvent', (_message.Message,), {
  'DESCRIPTOR' : _MARKETEVENT,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.MarketEvent)
  })
_sym_db.RegisterMessage(MarketEvent)

TxErrorEvent = _reflection.GeneratedProtocolMessageType('TxErrorEvent', (_message.Message,), {
  'DESCRIPTOR' : _TXERROREVENT,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TxErrorEvent)
  })
_sym_db.RegisterMessage(TxErrorEvent)

TimeUpdate = _reflection.GeneratedProtocolMessageType('TimeUpdate', (_message.Message,), {
  'DESCRIPTOR' : _TIMEUPDATE,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TimeUpdate)
  })
_sym_db.RegisterMessage(TimeUpdate)

TransferResponses = _reflection.GeneratedProtocolMessageType('TransferResponses', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERRESPONSES,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TransferResponses)
  })
_sym_db.RegisterMessage(TransferResponses)

PositionResolution = _reflection.GeneratedProtocolMessageType('PositionResolution', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONRESOLUTION,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.PositionResolution)
  })
_sym_db.RegisterMessage(PositionResolution)

LossSocialization = _reflection.GeneratedProtocolMessageType('LossSocialization', (_message.Message,), {
  'DESCRIPTOR' : _LOSSSOCIALIZATION,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.LossSocialization)
  })
_sym_db.RegisterMessage(LossSocialization)

TradeSettlement = _reflection.GeneratedProtocolMessageType('TradeSettlement', (_message.Message,), {
  'DESCRIPTOR' : _TRADESETTLEMENT,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TradeSettlement)
  })
_sym_db.RegisterMessage(TradeSettlement)

SettlePosition = _reflection.GeneratedProtocolMessageType('SettlePosition', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEPOSITION,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.SettlePosition)
  })
_sym_db.RegisterMessage(SettlePosition)

SettleDistressed = _reflection.GeneratedProtocolMessageType('SettleDistressed', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEDISTRESSED,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.SettleDistressed)
  })
_sym_db.RegisterMessage(SettleDistressed)

MarketTick = _reflection.GeneratedProtocolMessageType('MarketTick', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTICK,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.MarketTick)
  })
_sym_db.RegisterMessage(MarketTick)

AuctionEvent = _reflection.GeneratedProtocolMessageType('AuctionEvent', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONEVENT,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.AuctionEvent)
  })
_sym_db.RegisterMessage(AuctionEvent)

BusEvent = _reflection.GeneratedProtocolMessageType('BusEvent', (_message.Message,), {
  'DESCRIPTOR' : _BUSEVENT,
  '__module__' : 'events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BusEvent)
  })
_sym_db.RegisterMessage(BusEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
