# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chain_events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='chain_events.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'\n\024io.vegaprotocol.vegaZ\037code.vegaprotocol.io/vega/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x63hain_events.proto\x12\x04vega\"l\n\x13\x42uiltinAssetDeposit\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x16\n\x06\x61mount\x18\x03 \x01(\x04R\x06\x61mount\"o\n\x16\x42uiltinAssetWithdrawal\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x16\n\x06\x61mount\x18\x03 \x01(\x04R\x06\x61mount\"\x96\x01\n\x11\x42uiltinAssetEvent\x12\x36\n\x07\x64\x65posit\x18\xe9\x07 \x01(\x0b\x32\x19.vega.BuiltinAssetDepositH\x00R\x07\x64\x65posit\x12?\n\nwithdrawal\x18\xea\x07 \x01(\x0b\x32\x1c.vega.BuiltinAssetWithdrawalH\x00R\nwithdrawalB\x08\n\x06\x61\x63tion\"4\n\x0e\x45RC20AssetList\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\"6\n\x10\x45RC20AssetDelist\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\"\xaa\x01\n\x0c\x45RC20Deposit\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\x12\x36\n\x17source_ethereum_address\x18\x02 \x01(\tR\x15sourceEthereumAddress\x12&\n\x0ftarget_party_id\x18\x03 \x01(\tR\rtargetPartyId\x12\x16\n\x06\x61mount\x18\x04 \x01(\tR\x06\x61mount\"\x96\x01\n\x0f\x45RC20Withdrawal\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\x12\x36\n\x17target_ethereum_address\x18\x02 \x01(\tR\x15targetEthereumAddress\x12\'\n\x0freference_nonce\x18\x03 \x01(\tR\x0ereferenceNonce\"\xa3\x02\n\nERC20Event\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12\x14\n\x05\x62lock\x18\x02 \x01(\x04R\x05\x62lock\x12\x36\n\nasset_list\x18\xe9\x07 \x01(\x0b\x32\x14.vega.ERC20AssetListH\x00R\tassetList\x12<\n\x0c\x61sset_delist\x18\xea\x07 \x01(\x0b\x32\x16.vega.ERC20AssetDelistH\x00R\x0b\x61ssetDelist\x12/\n\x07\x64\x65posit\x18\xeb\x07 \x01(\x0b\x32\x12.vega.ERC20DepositH\x00R\x07\x64\x65posit\x12\x38\n\nwithdrawal\x18\xec\x07 \x01(\x0b\x32\x15.vega.ERC20WithdrawalH\x00R\nwithdrawalB\x08\n\x06\x61\x63tion\"\x86\x01\n\nBTCDeposit\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\x12,\n\x12source_btc_address\x18\x02 \x01(\tR\x10sourceBtcAddress\x12&\n\x0ftarget_party_id\x18\x03 \x01(\tR\rtargetPartyId\"\xb2\x01\n\rBTCWithdrawal\x12\"\n\rvega_asset_id\x18\x01 \x01(\tR\x0bvegaAssetId\x12&\n\x0fsource_party_id\x18\x02 \x01(\tR\rsourcePartyId\x12,\n\x12target_btc_address\x18\x03 \x01(\tR\x10targetBtcAddress\x12\'\n\x0freference_nonce\x18\x04 \x01(\tR\x0ereferenceNonce\"\xa7\x01\n\x08\x42TCEvent\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12\x14\n\x05\x62lock\x18\x02 \x01(\x04R\x05\x62lock\x12-\n\x07\x64\x65posit\x18\xe9\x07 \x01(\x0b\x32\x10.vega.BTCDepositH\x00R\x07\x64\x65posit\x12\x36\n\nwithdrawal\x18\xea\x07 \x01(\x0b\x32\x13.vega.BTCWithdrawalH\x00R\nwithdrawalB\x08\n\x06\x61\x63tion\"+\n\x0f\x45thereumAddress\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"*\n\x0e\x42itcoinAddress\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\x9f\x01\n\nIdentifier\x12\x42\n\x10\x65thereum_address\x18\x01 \x01(\x0b\x32\x15.vega.EthereumAddressH\x00R\x0f\x65thereumAddress\x12?\n\x0f\x62itcoin_address\x18\x02 \x01(\x0b\x32\x14.vega.BitcoinAddressH\x00R\x0e\x62itcoinAddressB\x0c\n\nidentifier\"0\n\x0c\x41\x64\x64Validator\x12 \n\x02id\x18\x01 \x01(\x0b\x32\x10.vega.IdentifierR\x02id\"3\n\x0fRemoveValidator\x12 \n\x02id\x18\x01 \x01(\x0b\x32\x10.vega.IdentifierR\x02id\"\x8a\x01\n\x0eValidatorEvent\x12\x1b\n\tsource_id\x18\x01 \x01(\tR\x08sourceId\x12\'\n\x03\x61\x64\x64\x18\xe9\x07 \x01(\x0b\x32\x12.vega.AddValidatorH\x00R\x03\x61\x64\x64\x12(\n\x02rm\x18\xea\x07 \x01(\x0b\x32\x15.vega.RemoveValidatorH\x00R\x02rmB\x08\n\x06\x61\x63tion\"\xfd\x01\n\nChainEvent\x12\x13\n\x05tx_id\x18\x01 \x01(\tR\x04txId\x12\x14\n\x05nonce\x18\x02 \x01(\x04R\x05nonce\x12\x34\n\x07\x62uiltin\x18\xe9\x07 \x01(\x0b\x32\x17.vega.BuiltinAssetEventH\x00R\x07\x62uiltin\x12)\n\x05\x65rc20\x18\xea\x07 \x01(\x0b\x32\x10.vega.ERC20EventH\x00R\x05\x65rc20\x12#\n\x03\x62tc\x18\xeb\x07 \x01(\x0b\x32\x0e.vega.BTCEventH\x00R\x03\x62tc\x12\x35\n\tvalidator\x18\xec\x07 \x01(\x0b\x32\x14.vega.ValidatorEventH\x00R\tvalidatorB\x07\n\x05\x65ventB7\n\x14io.vegaprotocol.vegaZ\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
)




_BUILTINASSETDEPOSIT = _descriptor.Descriptor(
  name='BuiltinAssetDeposit',
  full_name='vega.BuiltinAssetDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.BuiltinAssetDeposit.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.BuiltinAssetDeposit.party_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.BuiltinAssetDeposit.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=136,
)


_BUILTINASSETWITHDRAWAL = _descriptor.Descriptor(
  name='BuiltinAssetWithdrawal',
  full_name='vega.BuiltinAssetWithdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.BuiltinAssetWithdrawal.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party_id', full_name='vega.BuiltinAssetWithdrawal.party_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='partyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.BuiltinAssetWithdrawal.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=249,
)


_BUILTINASSETEVENT = _descriptor.Descriptor(
  name='BuiltinAssetEvent',
  full_name='vega.BuiltinAssetEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BuiltinAssetEvent.deposit', index=0,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deposit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BuiltinAssetEvent.withdrawal', index=1,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withdrawal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.BuiltinAssetEvent.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=252,
  serialized_end=402,
)


_ERC20ASSETLIST = _descriptor.Descriptor(
  name='ERC20AssetList',
  full_name='vega.ERC20AssetList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.ERC20AssetList.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=456,
)


_ERC20ASSETDELIST = _descriptor.Descriptor(
  name='ERC20AssetDelist',
  full_name='vega.ERC20AssetDelist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.ERC20AssetDelist.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=512,
)


_ERC20DEPOSIT = _descriptor.Descriptor(
  name='ERC20Deposit',
  full_name='vega.ERC20Deposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.ERC20Deposit.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_ethereum_address', full_name='vega.ERC20Deposit.source_ethereum_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceEthereumAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_party_id', full_name='vega.ERC20Deposit.target_party_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='targetPartyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.ERC20Deposit.amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=685,
)


_ERC20WITHDRAWAL = _descriptor.Descriptor(
  name='ERC20Withdrawal',
  full_name='vega.ERC20Withdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.ERC20Withdrawal.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_ethereum_address', full_name='vega.ERC20Withdrawal.target_ethereum_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='targetEthereumAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_nonce', full_name='vega.ERC20Withdrawal.reference_nonce', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='referenceNonce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=838,
)


_ERC20EVENT = _descriptor.Descriptor(
  name='ERC20Event',
  full_name='vega.ERC20Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.ERC20Event.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='index', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.ERC20Event.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='block', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset_list', full_name='vega.ERC20Event.asset_list', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='assetList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset_delist', full_name='vega.ERC20Event.asset_delist', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='assetDelist', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.ERC20Event.deposit', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deposit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.ERC20Event.withdrawal', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withdrawal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.ERC20Event.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=841,
  serialized_end=1132,
)


_BTCDEPOSIT = _descriptor.Descriptor(
  name='BTCDeposit',
  full_name='vega.BTCDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.BTCDeposit.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_btc_address', full_name='vega.BTCDeposit.source_btc_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceBtcAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_party_id', full_name='vega.BTCDeposit.target_party_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='targetPartyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1269,
)


_BTCWITHDRAWAL = _descriptor.Descriptor(
  name='BTCWithdrawal',
  full_name='vega.BTCWithdrawal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vega_asset_id', full_name='vega.BTCWithdrawal.vega_asset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='vegaAssetId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_party_id', full_name='vega.BTCWithdrawal.source_party_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourcePartyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_btc_address', full_name='vega.BTCWithdrawal.target_btc_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='targetBtcAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_nonce', full_name='vega.BTCWithdrawal.reference_nonce', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='referenceNonce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1450,
)


_BTCEVENT = _descriptor.Descriptor(
  name='BTCEvent',
  full_name='vega.BTCEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.BTCEvent.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='index', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.BTCEvent.block', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='block', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BTCEvent.deposit', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deposit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BTCEvent.withdrawal', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withdrawal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.BTCEvent.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1453,
  serialized_end=1620,
)


_ETHEREUMADDRESS = _descriptor.Descriptor(
  name='EthereumAddress',
  full_name='vega.EthereumAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.EthereumAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1622,
  serialized_end=1665,
)


_BITCOINADDRESS = _descriptor.Descriptor(
  name='BitcoinAddress',
  full_name='vega.BitcoinAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.BitcoinAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1709,
)


_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='vega.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethereum_address', full_name='vega.Identifier.ethereum_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ethereumAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitcoin_address', full_name='vega.Identifier.bitcoin_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bitcoinAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier', full_name='vega.Identifier.identifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1712,
  serialized_end=1871,
)


_ADDVALIDATOR = _descriptor.Descriptor(
  name='AddValidator',
  full_name='vega.AddValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.AddValidator.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1873,
  serialized_end=1921,
)


_REMOVEVALIDATOR = _descriptor.Descriptor(
  name='RemoveValidator',
  full_name='vega.RemoveValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='vega.RemoveValidator.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=1974,
)


_VALIDATOREVENT = _descriptor.Descriptor(
  name='ValidatorEvent',
  full_name='vega.ValidatorEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_id', full_name='vega.ValidatorEvent.source_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add', full_name='vega.ValidatorEvent.add', index=1,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='add', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rm', full_name='vega.ValidatorEvent.rm', index=2,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rm', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='vega.ValidatorEvent.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1977,
  serialized_end=2115,
)


_CHAINEVENT = _descriptor.Descriptor(
  name='ChainEvent',
  full_name='vega.ChainEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='vega.ChainEvent.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='txId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='vega.ChainEvent.nonce', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nonce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='builtin', full_name='vega.ChainEvent.builtin', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='builtin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='erc20', full_name='vega.ChainEvent.erc20', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='erc20', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='btc', full_name='vega.ChainEvent.btc', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='btc', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.ChainEvent.validator', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='vega.ChainEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2118,
  serialized_end=2371,
)

_BUILTINASSETEVENT.fields_by_name['deposit'].message_type = _BUILTINASSETDEPOSIT
_BUILTINASSETEVENT.fields_by_name['withdrawal'].message_type = _BUILTINASSETWITHDRAWAL
_BUILTINASSETEVENT.oneofs_by_name['action'].fields.append(
  _BUILTINASSETEVENT.fields_by_name['deposit'])
_BUILTINASSETEVENT.fields_by_name['deposit'].containing_oneof = _BUILTINASSETEVENT.oneofs_by_name['action']
_BUILTINASSETEVENT.oneofs_by_name['action'].fields.append(
  _BUILTINASSETEVENT.fields_by_name['withdrawal'])
_BUILTINASSETEVENT.fields_by_name['withdrawal'].containing_oneof = _BUILTINASSETEVENT.oneofs_by_name['action']
_ERC20EVENT.fields_by_name['asset_list'].message_type = _ERC20ASSETLIST
_ERC20EVENT.fields_by_name['asset_delist'].message_type = _ERC20ASSETDELIST
_ERC20EVENT.fields_by_name['deposit'].message_type = _ERC20DEPOSIT
_ERC20EVENT.fields_by_name['withdrawal'].message_type = _ERC20WITHDRAWAL
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['asset_list'])
_ERC20EVENT.fields_by_name['asset_list'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['asset_delist'])
_ERC20EVENT.fields_by_name['asset_delist'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['deposit'])
_ERC20EVENT.fields_by_name['deposit'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_ERC20EVENT.oneofs_by_name['action'].fields.append(
  _ERC20EVENT.fields_by_name['withdrawal'])
_ERC20EVENT.fields_by_name['withdrawal'].containing_oneof = _ERC20EVENT.oneofs_by_name['action']
_BTCEVENT.fields_by_name['deposit'].message_type = _BTCDEPOSIT
_BTCEVENT.fields_by_name['withdrawal'].message_type = _BTCWITHDRAWAL
_BTCEVENT.oneofs_by_name['action'].fields.append(
  _BTCEVENT.fields_by_name['deposit'])
_BTCEVENT.fields_by_name['deposit'].containing_oneof = _BTCEVENT.oneofs_by_name['action']
_BTCEVENT.oneofs_by_name['action'].fields.append(
  _BTCEVENT.fields_by_name['withdrawal'])
_BTCEVENT.fields_by_name['withdrawal'].containing_oneof = _BTCEVENT.oneofs_by_name['action']
_IDENTIFIER.fields_by_name['ethereum_address'].message_type = _ETHEREUMADDRESS
_IDENTIFIER.fields_by_name['bitcoin_address'].message_type = _BITCOINADDRESS
_IDENTIFIER.oneofs_by_name['identifier'].fields.append(
  _IDENTIFIER.fields_by_name['ethereum_address'])
_IDENTIFIER.fields_by_name['ethereum_address'].containing_oneof = _IDENTIFIER.oneofs_by_name['identifier']
_IDENTIFIER.oneofs_by_name['identifier'].fields.append(
  _IDENTIFIER.fields_by_name['bitcoin_address'])
_IDENTIFIER.fields_by_name['bitcoin_address'].containing_oneof = _IDENTIFIER.oneofs_by_name['identifier']
_ADDVALIDATOR.fields_by_name['id'].message_type = _IDENTIFIER
_REMOVEVALIDATOR.fields_by_name['id'].message_type = _IDENTIFIER
_VALIDATOREVENT.fields_by_name['add'].message_type = _ADDVALIDATOR
_VALIDATOREVENT.fields_by_name['rm'].message_type = _REMOVEVALIDATOR
_VALIDATOREVENT.oneofs_by_name['action'].fields.append(
  _VALIDATOREVENT.fields_by_name['add'])
_VALIDATOREVENT.fields_by_name['add'].containing_oneof = _VALIDATOREVENT.oneofs_by_name['action']
_VALIDATOREVENT.oneofs_by_name['action'].fields.append(
  _VALIDATOREVENT.fields_by_name['rm'])
_VALIDATOREVENT.fields_by_name['rm'].containing_oneof = _VALIDATOREVENT.oneofs_by_name['action']
_CHAINEVENT.fields_by_name['builtin'].message_type = _BUILTINASSETEVENT
_CHAINEVENT.fields_by_name['erc20'].message_type = _ERC20EVENT
_CHAINEVENT.fields_by_name['btc'].message_type = _BTCEVENT
_CHAINEVENT.fields_by_name['validator'].message_type = _VALIDATOREVENT
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['builtin'])
_CHAINEVENT.fields_by_name['builtin'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['erc20'])
_CHAINEVENT.fields_by_name['erc20'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['btc'])
_CHAINEVENT.fields_by_name['btc'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
_CHAINEVENT.oneofs_by_name['event'].fields.append(
  _CHAINEVENT.fields_by_name['validator'])
_CHAINEVENT.fields_by_name['validator'].containing_oneof = _CHAINEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['BuiltinAssetDeposit'] = _BUILTINASSETDEPOSIT
DESCRIPTOR.message_types_by_name['BuiltinAssetWithdrawal'] = _BUILTINASSETWITHDRAWAL
DESCRIPTOR.message_types_by_name['BuiltinAssetEvent'] = _BUILTINASSETEVENT
DESCRIPTOR.message_types_by_name['ERC20AssetList'] = _ERC20ASSETLIST
DESCRIPTOR.message_types_by_name['ERC20AssetDelist'] = _ERC20ASSETDELIST
DESCRIPTOR.message_types_by_name['ERC20Deposit'] = _ERC20DEPOSIT
DESCRIPTOR.message_types_by_name['ERC20Withdrawal'] = _ERC20WITHDRAWAL
DESCRIPTOR.message_types_by_name['ERC20Event'] = _ERC20EVENT
DESCRIPTOR.message_types_by_name['BTCDeposit'] = _BTCDEPOSIT
DESCRIPTOR.message_types_by_name['BTCWithdrawal'] = _BTCWITHDRAWAL
DESCRIPTOR.message_types_by_name['BTCEvent'] = _BTCEVENT
DESCRIPTOR.message_types_by_name['EthereumAddress'] = _ETHEREUMADDRESS
DESCRIPTOR.message_types_by_name['BitcoinAddress'] = _BITCOINADDRESS
DESCRIPTOR.message_types_by_name['Identifier'] = _IDENTIFIER
DESCRIPTOR.message_types_by_name['AddValidator'] = _ADDVALIDATOR
DESCRIPTOR.message_types_by_name['RemoveValidator'] = _REMOVEVALIDATOR
DESCRIPTOR.message_types_by_name['ValidatorEvent'] = _VALIDATOREVENT
DESCRIPTOR.message_types_by_name['ChainEvent'] = _CHAINEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuiltinAssetDeposit = _reflection.GeneratedProtocolMessageType('BuiltinAssetDeposit', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETDEPOSIT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetDeposit)
  })
_sym_db.RegisterMessage(BuiltinAssetDeposit)

BuiltinAssetWithdrawal = _reflection.GeneratedProtocolMessageType('BuiltinAssetWithdrawal', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETWITHDRAWAL,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetWithdrawal)
  })
_sym_db.RegisterMessage(BuiltinAssetWithdrawal)

BuiltinAssetEvent = _reflection.GeneratedProtocolMessageType('BuiltinAssetEvent', (_message.Message,), {
  'DESCRIPTOR' : _BUILTINASSETEVENT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BuiltinAssetEvent)
  })
_sym_db.RegisterMessage(BuiltinAssetEvent)

ERC20AssetList = _reflection.GeneratedProtocolMessageType('ERC20AssetList', (_message.Message,), {
  'DESCRIPTOR' : _ERC20ASSETLIST,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20AssetList)
  })
_sym_db.RegisterMessage(ERC20AssetList)

ERC20AssetDelist = _reflection.GeneratedProtocolMessageType('ERC20AssetDelist', (_message.Message,), {
  'DESCRIPTOR' : _ERC20ASSETDELIST,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20AssetDelist)
  })
_sym_db.RegisterMessage(ERC20AssetDelist)

ERC20Deposit = _reflection.GeneratedProtocolMessageType('ERC20Deposit', (_message.Message,), {
  'DESCRIPTOR' : _ERC20DEPOSIT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Deposit)
  })
_sym_db.RegisterMessage(ERC20Deposit)

ERC20Withdrawal = _reflection.GeneratedProtocolMessageType('ERC20Withdrawal', (_message.Message,), {
  'DESCRIPTOR' : _ERC20WITHDRAWAL,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Withdrawal)
  })
_sym_db.RegisterMessage(ERC20Withdrawal)

ERC20Event = _reflection.GeneratedProtocolMessageType('ERC20Event', (_message.Message,), {
  'DESCRIPTOR' : _ERC20EVENT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ERC20Event)
  })
_sym_db.RegisterMessage(ERC20Event)

BTCDeposit = _reflection.GeneratedProtocolMessageType('BTCDeposit', (_message.Message,), {
  'DESCRIPTOR' : _BTCDEPOSIT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCDeposit)
  })
_sym_db.RegisterMessage(BTCDeposit)

BTCWithdrawal = _reflection.GeneratedProtocolMessageType('BTCWithdrawal', (_message.Message,), {
  'DESCRIPTOR' : _BTCWITHDRAWAL,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCWithdrawal)
  })
_sym_db.RegisterMessage(BTCWithdrawal)

BTCEvent = _reflection.GeneratedProtocolMessageType('BTCEvent', (_message.Message,), {
  'DESCRIPTOR' : _BTCEVENT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BTCEvent)
  })
_sym_db.RegisterMessage(BTCEvent)

EthereumAddress = _reflection.GeneratedProtocolMessageType('EthereumAddress', (_message.Message,), {
  'DESCRIPTOR' : _ETHEREUMADDRESS,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.EthereumAddress)
  })
_sym_db.RegisterMessage(EthereumAddress)

BitcoinAddress = _reflection.GeneratedProtocolMessageType('BitcoinAddress', (_message.Message,), {
  'DESCRIPTOR' : _BITCOINADDRESS,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BitcoinAddress)
  })
_sym_db.RegisterMessage(BitcoinAddress)

Identifier = _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIER,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.Identifier)
  })
_sym_db.RegisterMessage(Identifier)

AddValidator = _reflection.GeneratedProtocolMessageType('AddValidator', (_message.Message,), {
  'DESCRIPTOR' : _ADDVALIDATOR,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.AddValidator)
  })
_sym_db.RegisterMessage(AddValidator)

RemoveValidator = _reflection.GeneratedProtocolMessageType('RemoveValidator', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEVALIDATOR,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.RemoveValidator)
  })
_sym_db.RegisterMessage(RemoveValidator)

ValidatorEvent = _reflection.GeneratedProtocolMessageType('ValidatorEvent', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOREVENT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ValidatorEvent)
  })
_sym_db.RegisterMessage(ValidatorEvent)

ChainEvent = _reflection.GeneratedProtocolMessageType('ChainEvent', (_message.Message,), {
  'DESCRIPTOR' : _CHAINEVENT,
  '__module__' : 'chain_events_pb2'
  # @@protoc_insertion_point(class_scope:vega.ChainEvent)
  })
_sym_db.RegisterMessage(ChainEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
