# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracles/v1/oracle_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracles/v1/oracle_data.proto',
  package='oracles.v1',
  syntax='proto3',
  serialized_options=b'\n\037io.vegaprotocol.vega.oracles.v1Z*code.vegaprotocol.io/vega/proto/oracles/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1coracles/v1/oracle_data.proto\x12\noracles.v1\"\x9e\x01\n\nOracleData\x12\x19\n\x08pub_keys\x18\x01 \x03(\tR\x07pubKeys\x12(\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x14.oracles.v1.PropertyR\x04\x64\x61ta\x12(\n\x10matched_spec_ids\x18\x03 \x03(\tR\x0ematchedSpecIds\x12!\n\x0c\x62roadcast_at\x18\x04 \x01(\x03R\x0b\x62roadcastAt\"4\n\x08Property\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05valueBM\n\x1fio.vegaprotocol.vega.oracles.v1Z*code.vegaprotocol.io/vega/proto/oracles/v1b\x06proto3'
)




_ORACLEDATA = _descriptor.Descriptor(
  name='OracleData',
  full_name='oracles.v1.OracleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_keys', full_name='oracles.v1.OracleData.pub_keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='oracles.v1.OracleData.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matched_spec_ids', full_name='oracles.v1.OracleData.matched_spec_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchedSpecIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_at', full_name='oracles.v1.OracleData.broadcast_at', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='broadcastAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=203,
)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='oracles.v1.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='oracles.v1.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='oracles.v1.Property.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=257,
)

_ORACLEDATA.fields_by_name['data'].message_type = _PROPERTY
DESCRIPTOR.message_types_by_name['OracleData'] = _ORACLEDATA
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OracleData = _reflection.GeneratedProtocolMessageType('OracleData', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEDATA,
  '__module__' : 'oracles.v1.oracle_data_pb2'
  # @@protoc_insertion_point(class_scope:oracles.v1.OracleData)
  })
_sym_db.RegisterMessage(OracleData)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'oracles.v1.oracle_data_pb2'
  # @@protoc_insertion_point(class_scope:oracles.v1.Property)
  })
_sym_db.RegisterMessage(Property)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
