from . import oracle_data_pb2 as oracle_data
from . import oracle_data_pb2_grpc as oracle_data_grpc
from . import oracle_spec_pb2 as oracle_spec
from . import oracle_spec_pb2_grpc as oracle_spec_grpc

__all__ = [
    "oracle_data",
    "oracle_data_grpc",
    "oracle_spec",
    "oracle_spec_grpc",
]
